import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { LaunchConfigurationNameType } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteLaunchConfigurationCommand}.
 */
export interface DeleteLaunchConfigurationCommandInput extends LaunchConfigurationNameType {
}
/**
 * @public
 *
 * The output of {@link DeleteLaunchConfigurationCommand}.
 */
export interface DeleteLaunchConfigurationCommandOutput extends __MetadataBearer {
}
declare const DeleteLaunchConfigurationCommand_base: {
    new (input: DeleteLaunchConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteLaunchConfigurationCommandInput, DeleteLaunchConfigurationCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteLaunchConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteLaunchConfigurationCommandInput, DeleteLaunchConfigurationCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes the specified launch configuration.</p>
 *          <p>The launch configuration must not be attached to an Auto Scaling group. When this call
 *             completes, the launch configuration is no longer available for use.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DeleteLaunchConfigurationCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DeleteLaunchConfigurationCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = { // LaunchConfigurationNameType
 *   LaunchConfigurationName: "STRING_VALUE", // required
 * };
 * const command = new DeleteLaunchConfigurationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteLaunchConfigurationCommandInput - {@link DeleteLaunchConfigurationCommandInput}
 * @returns {@link DeleteLaunchConfigurationCommandOutput}
 * @see {@link DeleteLaunchConfigurationCommandInput} for command's `input` shape.
 * @see {@link DeleteLaunchConfigurationCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link ResourceInUseFault} (client fault)
 *  <p>The operation can't be performed because the resource is in use.</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To delete a launch configuration
 * ```javascript
 * // This example deletes the specified launch configuration.
 * const input = {
 *   "LaunchConfigurationName": "my-launch-config"
 * };
 * const command = new DeleteLaunchConfigurationCommand(input);
 * await client.send(command);
 * // example id: autoscaling-delete-launch-configuration-1
 * ```
 *
 */
export declare class DeleteLaunchConfigurationCommand extends DeleteLaunchConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: LaunchConfigurationNameType;
            output: {};
        };
        sdk: {
            input: DeleteLaunchConfigurationCommandInput;
            output: DeleteLaunchConfigurationCommandOutput;
        };
    };
}
